NAME
MooseX::Types::Locale::Language::Fast - Locale::Language related constraints for Moose (without coercions)
SYNOPSIS
{
package Foo;
use Moose;
use MooseX::Types::Locale::Language qw(
LanguageCode
LanguageName
);
has 'code'
=> ( isa => LanguageCode, is => 'rw' );
has 'name'
=> ( isa => LanguageName, is => 'rw' );
__PACKAGE__->meta->make_immutable;
}
my $foo = Foo->new(
code => 'JA',
name => 'JAPANESE',
);
print $foo->code; # 'JA' (not 'ja')
print $foo->name; # 'JAPANESE' (not 'Japanese')
DESCRIPTION
This module packages several Moose::Util::TypeConstraints, designed to work with the values of Locale::Language.
This module does not provide coercions. Therefore, it works faster than MooseX::Types::Locale::Language.
CONSTRAINTS
Alpha2Language-
A subtype of
Str, which should be defined in language code of ISO 639-1 alpha-2. LanguageCode-
Alias of
Alpha2Language. LanguageName-
A subtype of
Str, which should be defined in ISO 639-1 language name.
SEE ALSO
TO DO
See TO DO section of MooseX::Types::Locale::Language.
INCOMPATIBILITIES
None reported.
BUGS AND LIMITATIONS
No bugs have been reported.
Making suggestions and reporting bugs
Please report any found bugs, feature requests, and ideas for improvements to bug-moosex-types-locale-language at rt.cpan.org, or through the web interface at http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MooseX-Types-Locale-Language. I will be notified, and then you'll automatically be notified of progress on your bugs/requests as I make changes.
When reporting bugs, if possible, please add as small a sample as you can make of the code that produces the bug. And of course, suggestions and patches are welcome.
SUPPORT
You can find documentation for this module with the perldoc command.
perldoc MooseX::Types::Locale::Language::Fast
You can also look for information at:
- RT: CPAN's request tracker
-
http://rt.cpan.org/NoAuth/Bugs.html?Dist=MooseX-Types-Locale-Language
- AnnoCPAN: Annotated CPAN documentation
- Search CPAN
- CPAN Ratings
VERSION CONTROL
This module is maintained using git. You can get the latest version from git://github.com/gardejo/p5-moosex-types-locale-language.git.
AUTHOR
- MORIYA Masaki ("Gardejo")
-
<moriya at ermitejo dot com>, http://ttt.ermitejo.com/
COPYRIGHT
Copyright (c) 2009 by MORIYA Masaki ("Gardejo"), http://ttt.ermitejo.com.
This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself. See perlgpl and perlartistic.